@@ -108,9 +108,18 @@ public class Text extends HTMLPart {
 		int	spc_cnt = 0;
 		boolean	nbsp_f = false;
 		for ( int i = 0; i < line.length; i++ ) {
-			if ( line[i] == ' ' ) {
+			if ( line[i] == '\n' || line[i] == '\r' ) {
+				if ( i > 0 ) {
+					if ( line[i -1] == '\n' || line[i - 1] == '\r' ) {
+						if ( line[i] != line[i - 1] )   continue;
+					}
+				}
+				buf = buf.append( "\n" );
+				continue;
+			}
+			if ( line[i] == ' ' || line[i] == '\t' ) {
 				if ( mode == StringMode.TEXTAREA ) {
-					buf = buf.append( ' ' );
+					buf = buf.append( line[i] );
 					continue;
 				}
 				spc_cnt++;
@@ -233,6 +242,17 @@ public class Text extends HTMLPart {
 						continue;
 					}
 				}
+				else {
+					if ( line[i] == '\n' || line[i] == '\r' ) {
+						if ( i > 0 ) {
+							if ( line[i -1] == '\n' || line[i - 1] == '\r' ) {
+								if ( line[i] != line[i - 1] )	continue;
+							}
+						}
+						buf = buf.append( "\r\n" );
+						continue;
+					}
+				}
 			}
 			buf = buf.append( line[i] );
 		}
