@@ -57,3 +57,9 @@ public abstract class NullPage extends Page {
 
 }
 
+class NullPage4Alias extends NullPage {
+	public Forward input( RequestParameter req, Forward fw ) throws PageException {
+		return fw;
+	}
+}
+
