@@ -666,7 +666,8 @@ public abstract class Supervisor extends HttpServlet {
 				File	file = File.createTempFile( "dog", null );
 				file.deleteOnExit();
 				item.write( file );
-				ret.addItem( item.getFieldName(), item.getName(), file, item.getContentType() );
+				String[]	path = item.getName().split( "[\\\\/]" );
+				ret.addItem( item.getFieldName(), path[path.length - 1], file, item.getContentType() );
 			}
 		}
 		return ret;
