@@ -32,7 +32,6 @@ public class Tag extends HTMLPart {
 	private static final String[]	plain_tag = new String[] {
 		"code",
 		"comment",
-		"pre",
 		"plaintext",
 		"xmp",
 		"script",
@@ -393,7 +392,7 @@ public class Tag extends HTMLPart {
 		tag_name = tag_name.toLowerCase( Locale.ENGLISH );
 		StringMode	mode = StringMode.BODY;
 
-		if ( "textarea".equals( tag_name ) ) {
+		if ( "textarea".equals( tag_name ) || "pre".equals( tag_name ) ) {
 			mode = StringMode.TEXTAREA;
 		}
 		else if ( "td".equals( tag_name ) || "th".equals( tag_name ) ) {
@@ -453,7 +452,7 @@ public class Tag extends HTMLPart {
 		if ( !visible_f )	return;
 		w.print( getFirstTag() );
 		int	cnt = getHTMLPartCount();
-		mode = selectMode();
+		if ( mode != StringMode.TEXTAREA )	mode = selectMode();
 		for ( int i = 0; i < cnt; i++ ) {
 			getHTMLPart( i ).write( w, mode );
 		}
