@@ -16,7 +16,8 @@ public class Version {
 	 * Paraseleneのバージョン番号を表す文字列。
 	 */
 	public static final String VERSION = "@@@ver";
-	private static final String	TITLE = "Paraselene  Version " + VERSION;
+	private static final String	SITE = " (http://paraselene.sourceforge.jp/)";
+	private static final String	TITLE = "Paraselene1 " + VERSION + SITE;
 
 	/**
 	 * Paraseleneのアプリタイトル文字列。
